import * as React from 'react';
import { useAuth } from '@/hooks/useAuth';
import { AuthForm } from '@/components/AuthForm';
import { ProfileForm } from '@/components/ProfileForm';
import { Header } from '@/components/Header';
import { MetaHead } from '@/components/MetaHead';
import { CompactStatsCard } from '@/components/CompactStatsCard';
import { QuizCard } from '@/components/QuizCard';
import { QuizQuestion } from '@/components/QuizQuestion';
import { QuizResult } from '@/components/QuizResult';
import { QuizSelectionFlow } from '@/components/QuizSelectionFlow';
import { Footer } from '@/components/Footer';
import { Button } from '@/components/ui/button';
import { useQuiz } from '@/hooks/useQuiz';
import { supabase } from '@/integrations/supabase/client';
import { Users, BookOpen, Trophy, TrendingUp, Play, GraduationCap, Target, ArrowRight, Calendar, Crown, Gift, Hash, User, Clock, MapPin, Bell } from 'lucide-react';
import { Link } from 'react-router-dom';
import { Card, CardContent, CardHeader, CardTitle } from '@/components/ui/card';
import { Badge } from '@/components/ui/badge';
import SubscribeToBlogCard from '@/components/SubscribeToBlogCard';
import { useUniversities } from '@/hooks/useUniversities';
import { AIChatInterface } from '@/components/AIChatInterface';

type AppState = 'home' | 'course-selection' | 'quiz' | 'results';

const Index = () => {
  const {
    user,
    session,
    loading,
    setShowAuthModal
  } = useAuth();
  const [needsProfile, setNeedsProfile] = React.useState(false);
  const [appState, setAppState] = React.useState<AppState>('home');
  const [selectedCourseId, setSelectedCourseId] = React.useState<string>('');
  const [quizStartTime, setQuizStartTime] = React.useState<number>(0);
  const [competitionStats, setCompetitionStats] = React.useState({
    liveCompetitions: 2,
    pastCompetitions: 8,
    totalRewardsPaid: 450000,
    totalCompetitors: 1247
  });
  const [eventStats, setEventStats] = React.useState({
    upcomingEvents: 3,
    pastEvents: 12,
    totalAttendees: 2156,
    totalHours: 48
  });
  const [litCharIndex, setLitCharIndex] = React.useState(-1);
  const { data: allUniversities = [], isLoading: isUniversitiesLoading } = useUniversities();
  
  // Featured universities as specified by user
  const featuredUniversityNames = [
    'University of Ibadan',
    'University of Lagos', 
    'Obafemi Awolowo University',
    'Ahmadu Bello University',
    'Covenant University',
    'Federal University of Technology, Akure'
  ];
  
  const popularUniversities = allUniversities.filter(uni => 
    featuredUniversityNames.some(name => uni.name.includes(name))
  );

  // Helper function to render text with character spans
  const renderFlowingText = (text: string, startIndex: number) => {
    return text.split('').map((char, index) => (
      <span
        key={index}
        className={`flowing-char ${litCharIndex === startIndex + index ? 'lit' : ''}`}
        style={{ whiteSpace: char === ' ' ? 'pre' : 'normal' }}
      >
        {char === ' ' ? '\u00A0' : char}
      </span>
    ));
  };
  
  const {
    quizState,
    answerQuestion,
    skipQuestion,
    resetQuiz,
    getQuizResults,
    isLoading
  } = useQuiz(selectedCourseId);

  // Check if user needs to complete profile
  React.useEffect(() => {
    if (user && session) {
      checkProfileCompletion();
    }
  }, [user, session]);

  // Load real stats from database or API
  React.useEffect(() => {
    fetchCompetitionStats();
    fetchEventStats();
  }, []);

  // Flowing light animation effect
  React.useEffect(() => {
    if (appState === 'home') {
      const linkTexts = ['smart quizzes', 'AI note taking', 'CGPA calculator', 'friendly competitions'];
      const totalChars = linkTexts.reduce((sum, text) => sum + text.length, 0);
      
      const animationSequence = async () => {
        // Start after a small delay
        await new Promise(resolve => setTimeout(resolve, 1000));
        
        // Light up each character sequentially
        for (let i = 0; i < totalChars; i++) {
          setLitCharIndex(i);
          await new Promise(resolve => setTimeout(resolve, 80));
        }
        
        // Turn off the animation
        setLitCharIndex(-1);
      };
      
      animationSequence();
    }
  }, [appState]);
  
  
  const checkProfileCompletion = async () => {
    if (!user) return;
    try {
      const {
        data,
        error
      } = await supabase.from('profiles').select('username, university, faculty, department, academic_level_id').eq('id', user.id).single();
      if (error && error.code !== 'PGRST116') {
        console.error('Error checking profile:', error);
        return;
      }

      // Check if essential profile fields are missing
      const profileIncomplete = !data || !data.username || !data.university || !data.faculty || !data.department;
      setNeedsProfile(profileIncomplete);
    } catch (error) {
      console.error('Error checking profile completion:', error);
    }
  };

  const fetchCompetitionStats = async () => {
    try {
      // Using real figures as requested
      setCompetitionStats({
        liveCompetitions: 2,
        pastCompetitions: 8,
        totalRewardsPaid: 450000,
        totalCompetitors: 1247
      });
    } catch (error) {
      console.error('Error fetching competition stats:', error);
    }
  };

  const fetchEventStats = async () => {
    try {
      // Using real figures as requested
      setEventStats({
        upcomingEvents: 3,
        pastEvents: 12,
        totalAttendees: 2156,
        totalHours: 48
      });
    } catch (error) {
      console.error('Error fetching event stats:', error);
    }
  };

  // Show loading state
  if (loading) {
    return <div className="min-h-screen bg-black flex items-center justify-center">
        <div className="text-white text-xl">Loading...</div>
      </div>;
  }

  // Show profile form if profile is incomplete
  if (needsProfile) {
    return <ProfileForm user={user} onComplete={() => setNeedsProfile(false)} />;
  }

  // Featured courses (restored to 2 as requested)
  const featuredCourses = [
    {
      name: 'Introduction to Computer Science',
      code: 'CSC101',
      creditUnit: 3,
      lecturer: 'Dr. Adebayo Ogundimu',
      contact: 'a.ogundimu@uniabuja.edu.ng',
      hasNotes: true,
    },
    {
      name: 'General Mathematics',
      code: 'MTH101',
      creditUnit: 3,
      lecturer: 'Prof. Sarah Adeleke',
      contact: 's.adeleke@uniabuja.edu.ng',
      hasNotes: true,
    },
    { // New course added here
      name: 'Social Psychology',
      code: 'SOC205',
      creditUnit: 3,
      lecturer: 'Dr. Adeyanju Temitope Peter',
      contact: 'Adeyanju.temitope@uniabuja.edu.ng',
      hasNotes: false, // Assuming false as not specified, can be changed if notes exist
    },
    {
      name: 'Use of English I',
      code: 'GST101A',
      creditUnit: 2,
      lecturer: 'Dr. Tiamiyu Abiola',
      contact: 'tiamiyu.abiola@uniabuja.edu.ng',
      hasNotes: false,
    }
  ];
  
  const handleStartQuiz = () => {
    if (!user) {
      setShowAuthModal(true);
      return; // Prevent further execution if user is not logged in
    }
    setAppState('course-selection');
  };
  
  const handleCourseSelect = (courseId: string) => {
    console.log('Course selected:', courseId);
    setSelectedCourseId(courseId);
    setQuizStartTime(Date.now());
    setAppState('quiz');
  };
  
  const handleQuizComplete = () => {
    setAppState('results');
  };
  
  const handleRetryQuiz = () => {
    resetQuiz();
    setAppState('quiz');
  };
  
  const handleGoHome = () => {
    setAppState('home');
    setSelectedCourseId('');
  };
  
  const renderContent = () => {
    switch (appState) {
      case 'home':
        return <div className="space-y-12">
            {/* Welcome Section */}
            <section className="text-center py-3 animate-fade-in">
              <h1 className="font-normal text-3xl leading-tight sm:text-4xl md:text-5xl lg:text-[60px] lg:leading-[60px] mb-2">
                <span className="text-foreground">Learnable</span>{' '}
                <span className="ai-highlight">AI</span>
              </h1>
              <p className="font-normal text-foreground text-[18px] leading-[28px] mb-4 max-w-3xl mx-auto">
                AI study tools built for Nigerian students. Master your coursework with personalized{' '}
                <button 
                  onClick={handleStartQuiz} 
                  className="flowing-link cursor-pointer font-medium"
                >
                  {renderFlowingText('quizzes', 0)}
                </button>
                , smart{' '}
                <Link 
                  to="/ai-notes" 
                  className="flowing-link cursor-pointer font-medium"
                >
                  {renderFlowingText('note-taking', 7)}
                </Link>
                , and accurate{' '}
                <Link 
                  to="/grade-calculator" 
                  className="flowing-link cursor-pointer font-medium"
                >
                  {renderFlowingText('CGPA calculation', 19)}
                </Link>
                {' '}- all in one platform.
              </p>
              <div className="flex justify-center mb-3">
                <Button 
                  onClick={handleStartQuiz} 
                  className="gradient-primary font-semibold hover:opacity-90 smooth-transition shadow-lg hover:shadow-xl w-[154px] h-10 py-2 px-4"
                  style={{ color: '#282c34' }}
                >
                  Start Quiz
                </Button>
              </div>
            </section>

            {/* AI Chat Interface - Positioned closer to Start Quiz button */}
            <section className="mt-1">
              <AIChatInterface />
            </section>

            {/* Compact Stats Section */}
            <section className="my-8">
              <CompactStatsCard />
            </section>

            {/* Featured Courses Preview */}
            <section className="text-center my-6">
              <h2 className="section-title mb-4">
                Featured Courses
              </h2>
              <div className="grid grid-cols-1 md:grid-cols-2 gap-4 max-w-3xl mx-auto">
                {featuredCourses.map((course, index) => 
                  <QuizCard 
                    key={index}
                    courseName={course.name}
                    courseCode={course.code}
                    creditUnit={course.creditUnit}
                    lecturer={course.lecturer}
                    contact={course.contact}
                    hasNotes={course.hasNotes}
                    onStartQuiz={() => handleStartQuiz()}
                    onReadNotes={() => console.log('Attempting to read notes for:', course.name)}
                  />
                )}
              </div>
            </section>

            {/* Competitions and Events Section */}
            <section className="text-center my-6">
              <h2 className="section-title mb-4">
                Competitions and Events
              </h2>
              <div className="grid grid-cols-1 md:grid-cols-2 gap-4 max-w-3xl mx-auto">
                {/* Competition Card */}
                <Card className="glass-effect hover:glass-effect-light smooth-transition compact-card">
                  <CardHeader className="pb-3">
                    <CardTitle className="compact-card-title flex items-center space-x-2">
                      <Trophy className="w-4 h-4 md:w-5 md:h-5 text-yellow-500" />
                      <span>Competitions</span>
                    </CardTitle>
                    <div className="flex items-center space-x-2 compact-card-subtitle">
                      <Hash className="w-3 h-3 md:w-4 md:h-4" />
                      <span>CSC101</span>
                      <Badge variant="outline" className="ml-2 border-yellow-500/30 text-yellow-500 compact-badge">
                        ₦50,000 Prize
                      </Badge>
                    </div>
                  </CardHeader>
                  <CardContent className="space-y-2 p-3 pt-0">
                    <div className="space-y-1.5 compact-card-content">
                      <div className="flex items-center space-x-2">
                        <Target className="w-3 h-3 md:w-4 md:h-4" />
                        <span>Join global competitions and win amazing prizes</span>
                      </div>
                      <div className="flex items-center space-x-2">
                        <Trophy className="w-3 h-3 md:w-4 md:h-4" />
                        <span>Active: {competitionStats.liveCompetitions} competitions</span>
                      </div>
                      <div className="flex items-center space-x-2">
                        <Calendar className="w-3 h-3 md:w-4 md:h-4" />
                        <span>Past: {competitionStats.pastCompetitions} competitions completed</span>
                      </div>
                      <div className="flex items-center space-x-2">
                        <Users className="w-3 h-3 md:w-4 md:h-4" />
                        <span>Total Participants: {competitionStats.totalCompetitors.toLocaleString()}</span>
                      </div>
                    </div>
                    <div className="flex justify-center pt-2">
                      <Link to="/competition">
                        <Button 
                          className="gradient-primary text-black font-semibold hover:opacity-90 compact-button"
                        >
                          <Trophy className="w-3 h-3 md:w-4 md:h-4 mr-1.5" />
                          Join
                        </Button>
                      </Link>
                    </div>
                  </CardContent>
                </Card>

                {/* Event Card */}
                <Card className="glass-effect hover:glass-effect-light smooth-transition compact-card">
                  <CardHeader className="pb-3">
                    <CardTitle className="compact-card-title flex items-center space-x-2">
                      <Calendar className="w-4 h-4 md:w-5 md:h-5" style={{ color: '#ebb613' }} />
                      <span>Events</span>
                    </CardTitle>
                    <div className="flex items-center space-x-2 compact-card-subtitle">
                      <Hash className="w-3 h-3 md:w-4 md:h-4" />
                      <span>WEBINAR</span>
                      <Badge variant="outline" className="ml-2 compact-badge" style={{ color: '#ebb613', borderColor: 'rgba(235, 182, 19, 0.3)' }}>
                        upcoming
                      </Badge>
                    </div>
                  </CardHeader>
                  <CardContent className="space-y-2 p-3 pt-0">
                    <div className="space-y-1.5 compact-card-content">
                      <div className="flex items-center space-x-2">
                        <BookOpen className="w-3 h-3 md:w-4 md:h-4" />
                        <span>Events, webinars, tutorials & campus outreaches</span>
                      </div>
                      <div className="flex items-center space-x-2">
                        <Calendar className="w-3 h-3 md:w-4 md:h-4" />
                        <span>Total Events: {eventStats.upcomingEvents + eventStats.pastEvents}</span>
                      </div>
                      <div className="flex items-center space-x-2">
                        <Clock className="w-3 h-3 md:w-4 md:h-4" />
                        <span>Past Events: {eventStats.pastEvents}</span>
                      </div>
                      <div className="flex items-center space-x-2">
                        <Users className="w-3 h-3 md:w-4 md:h-4" />
                        <span>Active Events: {eventStats.upcomingEvents}</span>
                      </div>
                    </div>
                    <div className="flex justify-center pt-2">
                      <Link to="/events">
                        <Button 
                          className="gradient-primary text-black font-semibold hover:opacity-90 compact-button"
                        >
                          See Events
                        </Button>
                      </Link>
                    </div>
                  </CardContent>
                </Card>
              </div>
            </section>

            {/* Subscribe to Blog Card Section */}
            <section className="my-6">
              <SubscribeToBlogCard />
            </section>

            {/* Popular Universities Section */}
            <section className="text-center my-6">
              <h2 className="section-title mb-4">Popular Universities</h2>
              <p className="section-description mb-6 max-w-2xl mx-auto">
                Join thousands of students from Nigeria's top universities already using Learnable AI
              </p>
              
              {isUniversitiesLoading ? (
                <div className="flex items-center justify-center py-8">
                  <div className="animate-spin rounded-full h-6 w-6 border-b-2 border-primary"></div>
                </div>
              ) : (
                <div className="grid grid-cols-2 md:grid-cols-2 gap-4 max-w-3xl mx-auto">
                  {popularUniversities.slice(0, 6).map((university) => (
                    <Link key={university.id} to={`/universities/${university.slug}`} className="block">
                      <Card className="glass-effect hover:glass-effect-light smooth-transition compact-card cursor-pointer">
                        <CardContent className="p-3 text-center">
                          <div className="mb-3">
                            <Badge variant="outline" className="mb-2 compact-badge">{university.location}</Badge>
                            <h3 className="compact-card-title">{university.shortName}</h3>
                            <p className="compact-card-content mt-1">{university.studentCount}+ students • {university.type}</p>
                          </div>
                          <Button className="gradient-primary text-black font-semibold w-full compact-button">
                            View Resources
                          </Button>
                        </CardContent>
                      </Card>
                    </Link>
                  ))}
                </div>
              )}
              
              {allUniversities.length > 6 && (
                <div className="mt-6 text-center">
                  <p className="compact-card-content mb-3">
                    ...and {allUniversities.length - 6} more universities available
                  </p>
                  <Button 
                    variant="outline" 
                    className="compact-button"
                    onClick={() => window.open('/universities', '_self')}
                  >
                    <BookOpen className="w-4 h-4 mr-2" />
                    Browse All Universities
                  </Button>
                </div>
              )}
            </section>

            {/* What is Learnable AI Section */}
            <section className="glass-effect rounded-xl compact-section p-4 md:p-6 text-center max-w-3xl mx-auto">
              <h2 className="section-title mb-3">What is Learnable AI</h2>
              <p className="section-description mb-4 max-w-2xl mx-auto">
                Nigeria's smartest academic assistant designed specifically for university students. 
                We provide AI-powered mock exams, CGPA calculators, study reminders, and comprehensive educational tools 
                to help you excel in your academic journey.
              </p>
              <Link to="/about">
                <Button className="gradient-primary font-semibold hover:opacity-90 smooth-transition shadow-lg hover:shadow-xl compact-button">
                  Read More
                  <ArrowRight className="w-3 h-3 md:w-4 md:h-4 ml-1.5" />
                </Button>
              </Link>
            </section>
          </div>;
      case 'course-selection':
        return <QuizSelectionFlow onBack={handleGoHome} onStartQuiz={handleCourseSelect} />;
      case 'quiz':
        if (isLoading) {
          return <div className="flex items-center justify-center min-h-[400px]">
              <div className="text-white text-xl">Loading quiz questions...</div>
            </div>;
        }
        if (!quizState.questions || quizState.questions.length === 0) {
          return <div className="flex flex-col items-center justify-center min-h-[400px] space-y-4">
              <div className="text-white text-xl">No quiz questions available</div>
              <Button onClick={handleGoHome}>Go Back</Button>
            </div>;
        }
        const currentQuestion = quizState.questions[quizState.currentQuestionIndex];
        return <QuizQuestion question={currentQuestion.question} options={currentQuestion.options} questionNumber={quizState.currentQuestionIndex + 1} totalQuestions={quizState.questions.length} timeLeft={quizState.timeLeft} onAnswer={answerIndex => {
          answerQuestion(answerIndex);
          if (quizState.currentQuestionIndex === quizState.questions.length - 1) {
            setTimeout(handleQuizComplete, 1000);
          }
        }} onSkip={() => {
          skipQuestion();
          if (quizState.currentQuestionIndex === quizState.questions.length - 1) {
            setTimeout(handleQuizComplete, 1000);
          }
        }} onTimeUp={() => {
          skipQuestion();
          if (quizState.currentQuestionIndex === quizState.questions.length - 1) {
            setTimeout(handleQuizComplete, 1000);
          }
        }} />;
      case 'results':
        const results = getQuizResults();
        const timeSpent = Math.floor((Date.now() - quizStartTime) / 1000);
        const correctAnswers = results.results.filter(r => r.isCorrect).length;
        const wrongAnswers = results.results.filter(r => !r.isCorrect && r.userAnswer !== null).length;
        const skippedAnswers = results.skippedQuestions;
        return <QuizResult score={results.score} totalQuestions={results.totalQuestions} correctAnswers={correctAnswers} wrongAnswers={wrongAnswers} skippedAnswers={skippedAnswers} timeSpent={timeSpent} courseRank={Math.floor(Math.random() * 50) + 1} // Mock ranking
        totalParticipants={Math.floor(Math.random() * 200) + 100} // Mock participants
        onRetry={handleRetryQuiz} onGoHome={handleGoHome} />;
      default:
        return null;
    }
  };
  
  return (
    <div className="min-h-screen bg-background flex flex-col">
      <MetaHead
        title="Learnable AI – Smart Academic Assistant for Nigerian Students"
        description="Smart AI-powered study assistant for Nigerian university students. Practice mock exams, calculate CGPA, get study reminders and more. Join thousands of students improving their grades!"
        keywords="Nigerian universities, student quiz app, AI learning, academic quiz, university education, study tools, exam preparation, Nigerian students, CGPA calculator, mock exams"
        ogUrl="https://learnable.fun/"
        ogImage="https://learnable.fun/assets/learnable-preview.jpg"
      />
      
      <Header />
      
      <main className="flex-1 pt-16 pb-12">
        <div className="container mx-auto px-4 sm:px-6 lg:px-8">
          {renderContent()}
        </div>
      </main>

      <Footer />
    </div>
  );
};

export default Index;
